/**
 * WordPress components that create the necessary UI elements for the block
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-components/
 */

 import { __ } from "@wordpress/i18n";

 import React, { useState, useEffect } from 'react';

 import classNames from "classnames";

 import {
	 InspectorControls,
	 useBlockProps
 } from '@wordpress/block-editor';

 import {
	 TextControl,
	 ToggleControl,
	 RangeControl,
	 Panel,
	 PanelBody
 } from '@wordpress/components';

 import ServerSideRender from '@wordpress/server-side-render';
  
 /**
  * The edit function describes the structure of your block in the context of the
  * editor. This represents what the editor will render when the block is used.
  *
  * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#edit
  *
  * @param {Object}   props               Properties passed to the function.
  * @param {Object}   props.attributes    Available block attributes.
  * @param {Function} props.setAttributes Function that updates individual attributes.
  *
  * @return {WPElement} Element to render.
  */

  function columnClassName(numColumns){
	if(numColumns == 1){
		return 'full-column'
	}
	else if(numColumns == 2){
		return 'half-column'
	}
	else if(numColumns == 3){
		return 'thirt-column'//substituir no css por third-column
	}
  }

  const slideClasses = 'slide-item-wrapper half-column img-left';

  export default function Edit ( props ) {
    const {
        attributes,
        setAttributes,
    } = props;


    const {
      titleBlock,
      jsonURL,
      showExcerpt,
      showAuthor,
      showImage,
      showImageCredit,
	  showImageOnFirstOnly,
      showCategory,
	  showDate,
	  showIdentificationOnDate,
      isSlide,
	  ppp,
      queryNumItems,
      selectColumns,
	  imageSize,
	  clientId
    } = attributes

	setAttributes( { clientId: props.clientId } ); 
	
	const [posts, setPosts] = useState([])

    useEffect(async () => {
			const url = new URL(jsonURL)
			url.searchParams.set('per_page', String(queryNumItems))
			try {
				const response = await window.fetch(url.toString(),{
					method: 'GET',
				})
				const data = await response.json()
				setPosts(data)
			} catch (error) {
				console.error(error)
			}

		}, [jsonURL, queryNumItems, setPosts])

	  return (

		<div { ...useBlockProps() }>
			<InspectorControls key="setting">
				<Panel>
					 <PanelBody title={__('Configurações do bloco')}>

						<TextControl
							label={ __('Identificação do bloco')}
							value={ titleBlock }
							onChange={ ( titleBlock ) => {
								setAttributes( { titleBlock } )
							} }
						/>

						<TextControl
							label={ __('Digite a URL da API')}
							value={ jsonURL }
							onChange={ ( jsonURL ) => {
								setAttributes( { jsonURL } )
							} }
						/>

						<ToggleControl
							label={ __( 'Exibir como slide' ) }
							checked={ isSlide }
							onChange={ ( value ) =>
								setAttributes( { isSlide: value } )
							}												
						/>
						{isSlide &&(
							
							<RangeControl
							label={ __( 'Itens por página' )}
							value={ ppp }
							onChange= {(value) => {
								setAttributes({ ppp: value});
							}}
							min={ 1 }
							/>

						)
						}

						<RangeControl
							label={ __( 'Colunas' )}
							value={ selectColumns }
							onChange= {(value) => {
								setAttributes({ selectColumns: value});
							}}
							min={ 1 }
							max={ 3 }

						/>

						<RangeControl
							label={ __( 'Quantidade de posts' )}
							value={ queryNumItems }
							onChange= {(value) => {
									setAttributes({ queryNumItems: value});
							}}
							min={ 1 }

						/>
					</PanelBody>
				</Panel>
				<Panel>
					 <PanelBody title={__('Configurações do post')}>
						<ToggleControl
							label={ __( 'Exibir resumo' ) }
							checked={ showExcerpt }
							onChange={ ( value ) =>
								setAttributes( { showExcerpt: value } )
							}
						/>

						<ToggleControl
							label={ __( 'Exibir autor' ) }
							checked={ showAuthor }
							onChange={ ( value ) =>
								setAttributes( { showAuthor: value } )
							}
						/>

						<ToggleControl
							label={ __( 'Exibir imagem destacada' ) }
							checked={ showImage }
							onChange={ ( value ) =>
								setAttributes( { showImage: value } )
							}
						/>
						{ showImage && 
							<TextControl
								label={ __('Tamanho das imagens (slug)')}
								value={ imageSize }
								onChange={ ( imageSize ) => {
									setAttributes( { imageSize } )
								} }
							/>
						}

						<ToggleControl
							label={ __( 'Exibir crédito da foto' ) }
							checked={ showImageCredit }
							onChange={ ( value ) =>
								setAttributes( { showImageCredit: value } )
							}
						/>
						<ToggleControl
							label={ __( 'Exibir imagem destacada somente no primeiro post' ) }
							checked={ showImage && showImageOnFirstOnly }
							onChange={ ( value ) =>
								setAttributes( { showImageOnFirstOnly: value } )
							}
						/>

						<ToggleControl
							label={ __( 'Exibir a categoria' ) }
							checked={ showCategory }
							onChange={ ( value ) =>
								setAttributes( { showCategory: value } )
							}

						/>

						<ToggleControl
							label={ __( 'Exibir a data' ) }
							checked={ showDate }
							onChange={ ( value ) =>
								setAttributes( { showDate: value } )
							}

						/>
						<ToggleControl
							label={ __( 'Exibir identificação ao lado da data' ) }
							checked={ showIdentificationOnDate }
							onChange={ ( value ) =>
								setAttributes( { showIdentificationOnDate: value } )
							}

						/>

					</PanelBody>
				</Panel>
			</InspectorControls>


			<div className="configBlock">
				<header><p>{titleBlock}</p></header>
				<ServerSideRender
					block="hacklab-blocks/hacklab-fetch-posts-api"
					attributes={ attributes }
				/>
			</div>
		 </div>

	 );
 }
